@@ -53,7 +53,6 @@ import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import static com.openexchange.mail.mime.converters.MimeMessageConverter.saveChanges;
 import static com.openexchange.mail.mime.utils.MimeMessageUtility.parseAddressList;
 import static com.openexchange.mail.text.TextProcessing.performLineFolding;
-import static java.util.regex.Matcher.quoteReplacement;
 import java.io.IOException;
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
@@ -74,11 +73,11 @@ import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.NoSuchProviderException;
 import javax.mail.Transport;
-import javax.mail.internet.IDNA;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMultipart;
+import javax.mail.internet.idn.IDNA;
 import javax.security.auth.Subject;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Filter;
@@ -91,6 +90,7 @@ import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Java7ConcurrentLinkedQueue;
+import com.openexchange.java.StringAllocator;
 import com.openexchange.log.LogProperties;
 import com.openexchange.log.Props;
 import com.openexchange.mail.MailExceptionCode;
@@ -131,6 +131,11 @@ public final class SMTPTransport extends MailTransport {
 
     private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SMTPTransport.class));
 
+    /**
+     * The SMTP protocol name.
+     */
+    private static final String SMTP = SMTPProvider.PROTOCOL_SMTP.getName();
+
     private static final class SaslSmtpLoginAction implements PrivilegedExceptionAction<Object> {
 
         private final Transport transport;
@@ -269,7 +274,7 @@ public final class SMTPTransport extends MailTransport {
 
     /**
      * Checks if Kerberos authentication is supposed to be performed.
-     * 
+     *
      * @return <code>true</code> for Kerberos authentication; otherwise <code>false</code>
      */
     private boolean isKerberosAuth() {
@@ -309,7 +314,7 @@ public final class SMTPTransport extends MailTransport {
                     this.kerberosSubject = (Subject) session.getParameter(KERBEROS_SESSION_SUBJECT);
                     final boolean kerberosAuth = isKerberosAuth();
                     if (kerberosAuth) {
-                        smtpProps.put("mail.smtp.auth", "true"); 
+                        smtpProps.put("mail.smtp.auth", "true");
                         smtpProps.put("mail.smtp.sasl.enable", "true");
                         smtpProps.put("mail.smtp.sasl.authorizationid", smtpConfig.getLogin());
                         smtpProps.put("mail.smtp.sasl.mechanisms", (kerberosAuth ? "GSSAPI" : "PLAIN"));
@@ -418,15 +423,18 @@ public final class SMTPTransport extends MailTransport {
     }
 
     private SMTPConfig getTransportConfig0() throws OXException {
-        if (cachedSmtpConfig == null) {
+        SMTPConfig tmp = cachedSmtpConfig;
+        if (tmp == null) {
             synchronized (this) {
-                if (cachedSmtpConfig == null) {
-                    cachedSmtpConfig = TransportConfig.getTransportConfig(new SMTPConfig(), session, accountId);
-                    cachedSmtpConfig.setTransportProperties(createNewMailProperties());
+                tmp = cachedSmtpConfig;
+                if (tmp == null) {
+                    tmp = TransportConfig.getTransportConfig(new SMTPConfig(), session, accountId);
+                    tmp.setTransportProperties(createNewMailProperties());
+                    cachedSmtpConfig = tmp;
                 }
             }
         }
-        return cachedSmtpConfig;
+        return tmp;
     }
 
     private static final String ACK_TEXT =
@@ -544,7 +552,7 @@ public final class SMTPTransport extends MailTransport {
              * Transport message
              */
             final long start = System.currentTimeMillis();
-            final Transport transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
+            final Transport transport = getSMTPSession().getTransport(SMTP);
             try {
                 final String server = IDNA.toASCII(smtpConfig.getServer());
                 final int port = smtpConfig.getPort();
@@ -592,7 +600,7 @@ public final class SMTPTransport extends MailTransport {
             checkRecipients(recipients);
             try {
                 final long start = System.currentTimeMillis();
-                final Transport transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
+                final Transport transport = getSMTPSession().getTransport(SMTP);
                 try {
                     final String server = IDNA.toASCII(smtpConfig.getServer());
                     final int port = smtpConfig.getPort();
@@ -670,7 +678,7 @@ public final class SMTPTransport extends MailTransport {
                         System.currentTimeMillis() - startPrep).append("msec").toString());
                 }
                 final long start = System.currentTimeMillis();
-                final Transport transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
+                final Transport transport = getSMTPSession().getTransport(SMTP);
                 try {
                     final String server = IDNA.toASCII(smtpConfig.getServer());
                     final int port = smtpConfig.getPort();
@@ -780,7 +788,7 @@ public final class SMTPTransport extends MailTransport {
         // Connect to SMTP server
         final Transport transport;
         try {
-            transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
+            transport = getSMTPSession().getTransport(SMTP);
         } catch (final NoSuchProviderException e) {
             throw MimeMailException.handleMessagingException(e);
         }
@@ -878,7 +886,7 @@ public final class SMTPTransport extends MailTransport {
         if (null == logProperties) {
             return getStaticHostName();
         }
-        final String serverName = logProperties.get("com.openexchange.ajp13.serverName");
+        final String serverName = logProperties.get(LogProperties.Name.AJP_SERVER_NAME);
         if (null == serverName) {
             return getStaticHostName();
         }
@@ -893,4 +901,41 @@ public final class SMTPTransport extends MailTransport {
         return staticHostName;
     }
 
+    private static String quoteReplacement(final String str) {
+        return isEmpty(str) ? "" : quoteReplacement0(str);
+    }
+
+    private static String quoteReplacement0(final String s) {
+        if ((s.indexOf('\\') == -1) && (s.indexOf('$') == -1)) {
+            return s;
+        }
+        final int length = s.length();
+        final StringAllocator sb = new StringAllocator(length << 1);
+        for (int i = 0; i < length; i++) {
+            final char c = s.charAt(i);
+            if (c == '\\') {
+                sb.append('\\');
+                sb.append('\\');
+            } else if (c == '$') {
+                sb.append('\\');
+                sb.append('$');
+            } else {
+                sb.append(c);
+            }
+        }
+        return sb.toString();
+    }
+
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
 }
